@@ -1,14 +1,13 @@
 """
 Tools for pulling and parsing stream data from Strava.
 """
-
 from datetime import timedelta
 import pandas as pd
 from pandas import TimedeltaIndex
 from runpandas import _utils as utils
 from runpandas.types import Activity
 from runpandas.types import columns
-from stravalib.client import Client
+from runpandas.io.strava._client import StravaClient
 
 
 COLUMNS_SCHEMA = {
@@ -50,12 +49,9 @@ def gen_records(streams):
 
 def read_strava(
     activity_id,
-    access_token,
-    refresh_token=None,
-    client_id=None,
-    client_secret=None,
+    client=None,
     to_df=False,
-    **kwargs
+    **kwargs,
 ):
     """
     This method loads the activity data from Strava into a Pandas DataFrame or
@@ -85,10 +81,9 @@ def read_strava(
     Return a obj:`runpandas.Activity` if `to_df=True`, otherwise
              a :obj:`pandas.DataFrame` will be returned.
     """
-
-    client = Client()
-    client.access_token = access_token
-    client.refresh_token = refresh_token
+    if client is None:
+        client = StravaClient()
+    client.refresh()
 
     activity = client.get_activity(activity_id)
 
